@@ -68,7 +68,7 @@
 #'     myGESCRSS <- get_gescrss(years = 2021, regions = "s")
 #'   }
 
-get_gescrss <- function(years     = 2011:2021,
+get_gescrss <- function(years     = 2011:2022,
                         regions   = c("mw", "ne", "s", "w"),
                         dir       = NULL,
                         proceed   = FALSE,
@@ -81,6 +81,7 @@ get_gescrss <- function(years     = 2011:2021,
       if(!is.null(dir)){
         if(cache %in% list.files(dir)){
 
+          message("Note: you specified years and a cache file. If the cache file exists, 'years' is ignored.")
           return(readRDS( gsub("//", "/", paste0(dir, "/", cache))))
 
         }
@@ -92,7 +93,7 @@ get_gescrss <- function(years     = 2011:2021,
     ymax <- max(as.numeric(years), na.rm = TRUE)
     ymin <- min(as.numeric(years), na.rm = TRUE)
     if(ymin < 2011) stop("Data not available prior to 2011.")
-    if(ymax > 2021) stop("Data not available beyond 2021.")
+    if(ymax > 2022) stop("Data not available beyond 2022.")
 
 
   # Check regions
@@ -115,9 +116,19 @@ get_gescrss <- function(years     = 2011:2021,
       dir.create(dest_raw,   showWarnings = FALSE)
       dir.create(dest_prepd, showWarnings = FALSE)
 
-      download_gescrss(years = years, dest_raw = dest_raw, dest_prepd = dest_prepd, regions = regions)
+      download_gescrss(
+        years = years,
+        dest_raw = dest_raw,
+        dest_prepd = dest_prepd,
+        regions = regions)
 
-      return(use_gescrss(dir = dir, prepared_dir = dest_prepd, cache = cache))
+      return(
+        use_gescrss(
+          dir = dir,
+          prepared_dir = dest_prepd,
+          cache = cache
+          )
+        )
 
     }
 
